<?php 

require "database.php";

define("THRESHOLD", 0.015);

class TableSide
{
	var $actualColour;
	var $games = 0;
	var $wins = 0;
	var $backGoals = 0;
	var $frontGoals = 0;
	var $shutouts = 0;
	
	function TableSide($colour)
	{
		$this->actualColour = $colour;
	}
	
	function getTotalGoals()
	{
		return ($this->backGoals + $this->frontGoals);
	}
	
	function getLossPercent()
	{
		if ($this->games > 0)
		{
			return round( ($this->games - $this->wins) / $this->games * 100 );
		}
		else
		{
			return 0;
		}
	}
	
	function getTotalWinsPercent()
	{
		if ($this->games > 0)
		{
			return round($this->wins / $this->games * 100);
		}
		else
		{
			return 0;
		}	
	}
	
	function getShutoutPercent()
	{
		if ($this->wins > 0)
		{
			return round($this->shutouts / $this->wins * 100);
		}
		else
		{
			return 0;
		}
	}
	
	function getFrontPercent()
	{
		if ($this->getTotalGoals() > 0)
		{
			return round($this->frontGoals / $this->getTotalGoals() * 100);
		}
		else
		{
			return 0;
		}
	}
	
	function getBackPercent()
	{
		if ($this->getTotalGoals() > 0)
		{
			return round($this->backGoals / $this->getTotalGoals() * 100);
		}
		else
		{
			return 0;
		}
	}
	
} // class TableSide
	
class Team
{
	var $backPlayer;
	var $frontPlayer;
	
	var $blueGames = 0;
	var $whiteGames = 0;
	
	var $blueBackGoals = 0;
	var $blueFrontGoals = 0;
	var $whiteBackGoals = 0;
	var $whiteFrontGoals = 0;
	
	var $blueWins = 0;
	var $whiteWins = 0;
	
	var $blueShutouts = 0;
	var $whiteShutouts = 0;
	
	var $blueShutoutLosses = 0;
	var $whiteShutoutLosses = 0;
	
	function Team($back, $front)
	{
		$this->backPlayer = $back;
		$this->frontPlayer = $front;
	}
	
	// games
	function getTotalGames()
	{
		return ($this->blueGames + $this->whiteGames);
	}
	
	// goals
	function getTotalGoals()
	{
		return ($this->blueBackGoals + $this->blueFrontGoals + $this->whiteBackGoals + $this->whiteFrontGoals);
	}
	
	function getBackGoals()
	{
		return ($this->blueBackGoals + $this->whiteBackGoals);
	}
	
	function getFrontGoals()
	{
		return ($this->blueFrontGoals + $this->whiteFrontGoals);
	}
	
	function getAvgGoals()
	{
		if ($this->getTotalGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return (round ($this->getTotalGoals() / $this->getTotalGames()));
		}
	}
	
	function getAvgFrontGoals()
	{
		if ($this->getTotalGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return round($this->getFrontGoals() / $this->getTotalGames());
		}
	}
	
	function getAvgBackGoals()
	{
		if ($this->getTotalGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return round($this->getBackGoals() / $this->getTotalGames());
		}
	}

	function getFrontGoalsPercent()
	{
		if ($this->getTotalGoals() > 0)
		{
			return round($this->getFrontGoals() / $this->getTotalGoals() * 100);
		}
		else
		{
			return 0;
		}
	}
	
	function getBackGoalsPercent()
	{
		if ($this->getTotalGoals() > 0)
		{
			return round($this->getBackGoals() / $this->getTotalGoals() * 100);
		}
		else
		{
			return 0;
		}
	}

/* percents of all table goals	
	function getFrontGoalsPercent($side1, $side2)
	{
		$allFrontGoals = $side1->frontGoals + $side2->frontGoals;
		if ($allFrontGoals > 0)
		{
			return round($this->getFrontGoals() / $allFrontGoals * 100);
		}
		else
		{
			return 0;
		}
	}
	
	function getBackGoalsPercent($side1, $side2)
	{
		$allBackGoals = $side1->backGoals + $side2->backGoals;
		if ($allBackGoals > 0)
		{
			return round($this->getBackGoals() / $allBackGoals * 100);
		}
		else
		{
			return 0;
		}
	}
	
	function getTotalGoalsPercent($side1, $side2)
	{
		$allGoals = $side1->getTotalGoals() + $side2->getTotalGoals();
		if ($allGoals > 0)
		{
			return round($this->getTotalGoals() / $allGoals * 100);
		}
		else
		{
			return 0;
		}
	}
*/

	// wins
	function getTotalWins()
	{
		return ($this->blueWins + $this->whiteWins);
	}
	
	function getTotalWinsPercent()
	{
		if ($this->getTotalGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return round($this->getTotalWins() / $this->getTotalGames() * 100);
		}
	}
	
	function getWinningOdds()
	{
		if ($this->getTotalGames() == 0)
		{
			return "<em>n/a</em>"; 
		}
		if ($this->getTotalWinsPercent() == 0) 
		{
			return "1:" . ($this->getTotalGames() + 1);
		}
		else 
		{
			return "1:" . round(100 / $this->getTotalWinsPercent());
		}
	}
	
	// losses
	function getTotalLosses()
	{
		return ($this->getTotalGames() - $this->getTotalWins());
	}
	
	function getBlueLosses()
	{
		return ($this->blueGames - $this->blueWins);
	}
	
	function getWhiteLosses()
	{
		return ($this->whiteGames - $this->whiteWins);
	}
	
	function getTotalLossesPercent()
	{
		if ($this->getTotalGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return round($this->getTotalLosses() / $this->getTotalGames() * 100);
		}
	}
	
	// shutouts
	function getShutouts()
	{
		return ($this->whiteShutouts + $this->blueShutouts);
	}
	
	// shutout losses
	function getShutoutLosses()
	{
		return ($this->whiteShutoutLosses + $this->blueShutoutLosses);
	}

} // class Team

function generateTeamHash($player1, $player2)
{
	if ($player1 > $player2)
	{
		return $player2 ."-". $player1;
	}
	else if ($player1 < $player2)
	{
		return $player1 ."-". $player2;
	}
	else
	{
		echo "Incorrect usage of generateTeamHash()";
		return -1;
	}
}

function generateTeamKey($back, $front)
{
	return $back ."-". $front;
}

class Player
{
	var $pid;
	var $firstName;
	var $lastName;
	
	var $blueBackGames = 0;
	var $blueFrontGames = 0;
	var $whiteBackGames = 0;
	var $whiteFrontGames = 0;
	var $blueSingleGames = 0;
	var $whiteSingleGames = 0;
	
	var $blueBackGoals = 0;
	var $blueFrontGoals = 0;
	var $whiteBackGoals = 0;
	var $whiteFrontGoals = 0;
	
	var $blueBackWins = 0;
	var $blueFrontWins = 0;
	var $blueSingleWins = 0;
	var $whiteBackWins = 0;
	var $whiteFrontWins = 0;
	var $whiteSingleWins = 0;
	
	var $blueBackShutouts = 0;
	var $blueFrontShutouts = 0;
	var $blueSingleShutouts = 0;
	var $whiteBackShutouts = 0;
	var $whiteFrontShutouts = 0;
	var $whiteSingleShutouts = 0;
	
	var $blueBackShutoutLosses = 0;
	var $blueFrontShutoutLosses = 0;
	var $blueSingleShutoutLosses = 0;
	var $whiteBackShutoutLosses = 0;
	var $whiteFrontShutoutLosses = 0;
	var $whiteSingleShutoutLosses = 0;
	
	function Player($playerid)
	{
		$this->pid = $playerid;
	}
	
	// games
	function getSingleGames()
	{
		return ($this->blueSingleGames + $this->whiteSingleGames);
	}
	
	function getFrontGames()
	{
		return ($this->blueFrontGames + $this->whiteFrontGames);
	}
	
	function getBackGames()
	{
		return ($this->blueBackGames + $this->whiteBackGames);
	}
	
	function getTotalGames()
	{
		return ($this->getBackGames() + $this->getFrontGames() + $this->getSingleGames());
	}
	
	function getBlueGames()
	{
		return ($this->blueBackGames + $this->blueFrontGames + $this->blueSingleGames);
	}
	
	function getWhiteGames()
	{
		return ($this->whiteBackGames + $this->whiteFrontGames + $this->whiteSingleGames);
	}
	
	// goals
	function getTotalGoals()
	{
		return ($this->blueBackGoals + $this->blueFrontGoals + $this->whiteBackGoals + $this->whiteFrontGoals);
	}
	
	function getBackGoals()
	{
		return ($this->blueBackGoals + $this->whiteBackGoals);
	}
	
	function getFrontGoals()
	{
		return ($this->blueFrontGoals + $this->whiteFrontGoals);
	}
	
	function getAvgGoals()
	{
		if ($this->getTotalGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return (round ($this->getTotalGoals() / $this->getTotalGames()));
		}
	}
	
	function getAvgFrontGoals()
	{
		if ($this->getFrontGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return (round ($this->getFrontGoals() / ($this->getFrontGames() + $this->getSingleGames()) ));
		}
	}
	
	function getAvgBackGoals()
	{
		if ($this->getBackGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return (round ($this->getBackGoals() / ($this->getBackGames() + $this->getSingleGames()) ));
		}
	}
	
	function getFrontGoalsPercent()
	{
		if ($this->getTotalGoals() > 0)
		{
			return round($this->getFrontGoals() / $this->getTotalGoals() * 100);
		}
		else
		{
			return 0;
		}
	}
	
	function getBackGoalsPercent()
	{
		if ($this->getTotalGoals() > 0)
		{
			return round($this->getBackGoals() / $this->getTotalGoals() * 100);
		}
		else
		{
			return 0;
		}
	}
	
/* percents of total table goals
	function getFrontGoalsPercent($side1, $side2)
	{
		$allFrontGoals = $side1->frontGoals + $side2->frontGoals;
		if ($allFrontGoals > 0)
		{
			return round($this->getFrontGoals() / $allFrontGoals * 100);
		}
		else
		{
			return 0;
		}
	}
	
	function getBackGoalsPercent($side1, $side2)
	{
		$allBackGoals = $side1->backGoals + $side2->backGoals;
		if ($allBackGoals > 0)
		{
			return round($this->getBackGoals() / $allBackGoals * 100);
		}
		else
		{
			return 0;
		}
	}
	
	function getTotalGoalsPercent($side1, $side2)
	{
		$allGoals = $side1->getTotalGoals() + $side2->getTotalGoals();
		if ($allGoals > 0)
		{
			return round($this->getTotalGoals() / $allGoals * 100);
		}
		else
		{
			return 0;
		}
	}
*/
	
	// wins
	function getBackWins()
	{
		return ($this->blueBackWins + $this->whiteBackWins);
	}
	
	function getFrontWins()
	{
		return ($this->blueFrontWins + $this->whiteFrontWins);
	}
	
	function getSingleWins()
	{
		return ($this->blueSingleWins + $this->whiteSingleWins);
	}
	
	function getTotalWins()
	{
		return ($this->getBackWins() + $this->getFrontWins() + $this->getSingleWins());
	}
	
	function getBlueWins()
	{
		return ($this->blueBackWins + $this->blueFrontWins + $this->blueSingleWins);
	}
	
	function getWhiteWins()
	{
		return ($this->whiteBackWins + $this->whiteFrontWins + $this->whiteSingleWins);
	}
	
	function getTotalWinsPercent()
	{
		if ($this->getTotalGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return round($this->getTotalWins() / $this->getTotalGames() * 100);
		}
	}
	
	function getWinningOdds()
	{
		if ($this->getTotalGames() == 0)
		{
			return "<em>n/a</em>"; 
		}
		if ($this->getTotalWinsPercent() == 0) 
		{
			return "1:" . ($this->getTotalGames() + 1);
		}
		else 
		{
			return "1:" . round(100 / $this->getTotalWinsPercent());
		}
	}
	
	// losses
	function getBackLosses()
	{
		return ($this->getBackGames() - $this->getBackWins());
	}
	
	function getFrontLosses()
	{
		return ($this->getFrontGames() - $this->getFrontWins());
	}
	
	function getSingleLosses()
	{
		return ($this->getSingleGames() - $this->getSingleWins());
	}
	
	function getTotalLosses()
	{
		return ($this->getBackLosses() + $this->getFrontLosses() + $this->getSingleLosses());
	}
	
	function getBlueLosses()
	{
		return ($this->getBlueGames() - $this->getBlueWins());
	}
	
	function getWhiteLosses()
	{
		return ($this->getWhiteGames() - $this->getWhiteWins());
	}
	
	function getTotalLossesPercent()
	{
		if ($this->getTotalGames() == 0) 
		{
			return 0;
		}
		else 
		{
			return round($this->getTotalLosses() / $this->getTotalGames() * 100);
		}
	}
	
	// shutouts
	function getBackShutouts()
	{
		return ($this->blueBackShutouts + $this->whiteBackShutouts);
	}
	
	function getFrontShutouts()
	{
		return ($this->blueFrontShutouts + $this->whiteFrontShutouts);
	}
	
	function getSingleShutouts()
	{
		return ($this->blueSingleShutouts + $this->whiteSingleShutouts);
	}
	
	function getShutouts()
	{
		return ($this->getBackShutouts() + $this->getFrontShutouts() + $this->getSingleShutouts());
	}
	
	function getBlueShutouts()
	{
		return ($this->blueBackShutouts + $this->blueFrontShutouts + $this->blueSingleShutouts);
	}
	
	function getWhiteShutouts()
	{
		return ($this->whiteBackShutouts + $this->whiteFrontShutouts + $this->whiteSingleShutouts);
	}
	
	function getShutoutPercent()
	{
		if ($this->getTotalWins() == 0) 
		{
			return 0;
		}
		else 
		{
			return round($this->getShutouts() / $this->getTotalWins() * 100);
		}
	}
	
	// shutout losses
	function getBackShutoutLosses()
	{
		return ($this->blueBackShutoutLosses + $this->whiteBackShutoutLosses);
	}
	
	function getFrontShutoutLosses()
	{
		return ($this->blueFrontShutoutLosses + $this->whiteFrontShutoutLosses);
	}
	
	function getSingleShutoutLosses()
	{
		return ($this->blueSingleShutoutLosses + $this->whiteSingleShutoutLosses);
	}
	
	function getShutoutLosses()
	{
		return ($this->getBackShutoutLosses() + $this->getFrontShutoutLosses() + $this->getSingleShutoutLosses());
	}
	
	function getBlueShutoutLosses()
	{
		return ($this->blueBackShutoutLosses + $this->blueFrontShutoutLosses + $this->blueSingleShutoutLosses);
	}
	
	function getWhiteShutoutLosses()
	{
		return ($this->whiteBackShutoutLosses + $this->whiteFrontShutoutLosses + $this->whiteSingleShutoutLosses);
	}
	
	function getShutoutLossesPercent()
	{
		if ($this->getTotalLosses() == 0) 
		{
			return 0;
		}
		else 
		{
			return round($this->getShutoutLosses() / $this->getTotalLosses() * 100);
		}
	}
	
} // class Player

// global variables
/*
$blueSide = new TableSide;
$whiteSide = new TableSide;
// stores all the players in an associative array
// pid is the key, and a Player object is the value
$players = array();
*/

function getSeasonData($seasonId, &$players, &$teams, &$blueSide, &$whiteSide)
{
	// get all the game data
	$query = "SELECT * FROM foosball_game WHERE seasonId = $seasonId";
	$result = mysql_query($query)
		or die("Query failed:[" . mysql_errno() . "] " . mysql_error()) .
			__LINE__ . " in file " . __FILE__;	
			
	$numgames = mysql_num_rows($result);
	
	$blueSide->games = $numgames;
	$whiteSide->games = $numgames;	
	
	while ($line = mysql_fetch_assoc( $result ))
	{
		// table stats
		$whiteSide->backGoals += $line['whiteBackScore'];
		$whiteSide->frontGoals += $line['whiteFrontScore'];
		
		$blueSide->backGoals += $line['blueBackScore'];
		$blueSide->frontGoals += $line['blueFrontScore'];
		
		// players
		$bbpid = $line['blueBackPlayer'];
		$bfpid = $line['blueFrontPlayer'];
		$wbpid = $line['whiteBackPlayer'];
		$wfpid = $line['whiteFrontPlayer'];
		
		// blue back player
		if (!array_key_exists($bbpid, $players))
		{
			$players[$bbpid] = new Player($bbpid);
		}
		
		$bteam = ($bbpid != $bfpid); 
		if ($bteam) // team game
		{
			// blue front player
			if (!array_key_exists($bfpid, $players))
			{	
				$players[$bfpid] = new Player($bfpid);
			}
			$players[$bbpid]->blueBackGames++;
			$players[$bfpid]->blueFrontGames++;
			
			// blue team
			$btid = generateTeamHash($bbpid, $bfpid);
			if (!array_key_exists($btid, $teams))
			{
				$teams[$btid] = new Team($bbpid, $bfpid);
			}
			$teams[$btid]->blueGames++;
			$teams[$btid]->blueBackGoals += $line['blueBackScore'];
			$teams[$btid]->blueFrontGoals += $line['blueFrontScore'];
		}
		else // 1-on-1 game
		{
			$players[$bbpid]->blueSingleGames++;
		}
		$players[$bbpid]->blueBackGoals += $line['blueBackScore'];
		$players[$bfpid]->blueFrontGoals += $line['blueFrontScore'];	
			
		// white back player
		if (!array_key_exists($wbpid, $players))
		{
			$players[$wbpid] = new Player($wbpid);
		}
		$wteam = ($wbpid != $wfpid);
		if ($wteam) // team game
		{
			// white front player
			if (!array_key_exists($wfpid, $players))
			{
				$players[$wfpid] = new Player($wfpid);
			}
			$players[$wbpid]->whiteBackGames++;
			$players[$wfpid]->whiteFrontGames++;
			
			// white team
			$wtid = generateTeamHash($wbpid, $wfpid);
			if (!array_key_exists($wtid, $teams))
			{
				$teams[$wtid] = new Team($wbpid, $wfpid);
			}
			$teams[$wtid]->whiteGames++;
			$teams[$wtid]->whiteBackGoals += $line['whiteBackScore'];
			$teams[$wtid]->whiteFrontGoals += $line['whiteFrontScore'];
		}
		else // 1-on-1 game
		{
			$players[$wbpid]->whiteSingleGames++;
		}
		$players[$wbpid]->whiteBackGoals += $line['whiteBackScore'];
		$players[$wfpid]->whiteFrontGoals += $line['whiteFrontScore'];
		
		// wins and shutouts
		if (($line['whiteFrontScore'] + $line['whiteBackScore']) <
				($line['blueFrontScore'] + $line['blueBackScore'])) // blue won
		{
			$blueSide->wins++;
			if ($bteam)
			{
				$players[$bbpid]->blueBackWins++;
				$players[$bfpid]->blueFrontWins++;
				$teams[$btid]->blueWins++;
			}
			else
			{
				$players[$bbpid]->blueSingleWins++;
			}
			if (($line['whiteFrontScore'] + $line['whiteBackScore']) == 0) // white was shutout
			{
				$blueSide->shutouts++;
				if ($bteam)
				{
					$players[$bbpid]->blueBackShutouts++;
					$players[$bfpid]->blueFrontShutouts++;
					$teams[$btid]->blueShutouts++;
					// no 1 vs. 2 support
					$players[$wbpid]->whiteBackShutoutLosses++;
					$players[$wfpid]->whiteFrontShutoutLosses++;
					$teams[$wtid]->whiteShutoutLosses++;
				}
				else
				{
					$players[$bbpid]->blueSingleShutouts++;
					$players[$wbpid]->whiteSingleShutoutLosses++;
				}					
			}
		}
		else // white won
		{
			$whiteSide->wins++;
			if ($wteam)
			{
				$players[$wbpid]->whiteBackWins++;
				$players[$wfpid]->whiteFrontWins++;
				$teams[$wtid]->whiteWins++;
			}
			else
			{
				$players[$wbpid]->whiteSingleWins++;
			}
			if (($line['blueFrontScore'] + $line['blueBackScore']) == 0)
			{
				$whiteSide->shutouts++;
				if ($wteam)
				{
					$players[$wbpid]->whiteBackShutouts++;
					$players[$wfpid]->whiteFrontShutouts++;
					$teams[$wtid]->whiteShutouts++;
					// no 1 vs. 2 support
					$players[$bbpid]->blueBackShutoutLosses++;
					$players[$bfpid]->blueFrontShutoutLosses++;
					$teams[$btid]->blueShutoutLosses++;
				}
				else
				{
					$players[$wbpid]->whiteSingleShutouts++;
					$players[$bbpid]->blueSingleShutoutLosses++;
				}
			}
		}
		
	} // while 
	
	mysql_free_result( $result );
	
	// get all the season players names
	$query = "SELECT sP.pid, p.firstName, p.lastName FROM foosball_leaguePlayer sP, foosball_player p WHERE sP.seasonId = $seasonId AND sP.pid = p.pid ORDER BY p.lastName";
	$result = mysql_query($query)
		or die("Query failed:[" . mysql_errno() . "] " . mysql_error()) .
			__LINE__ . " in file " . __FILE__;	
			
	$numplayers = mysql_num_rows($result);
	
	while ($line = mysql_fetch_assoc( $result ))
	{
		$pid = $line['pid'];
		$firstName = $line['firstName'];
		$lastName = $line['lastName'];
		
		if (!array_key_exists($pid, $players))
		{
			// player that played no games
			$players[$pid] = new Player($pid);
		}

		$players[$pid]->firstName = $firstName;
		$players[$pid]->lastName = $lastName;
	} // while
	
	mysql_free_result( $result );
	
} // getSeasonData()

function getTableTotalGoals($side1, $side2)
{
	return ($side1->getTotalGoals() + $side2->getTotalGoals());
}

function getPlayerTotalGoalsPercent($player, $side1, $side2)
{
	if (getTableTotalGoals($side1, $side2) != 0)
	{
		return round($player->getTotalGoals() / getTableTotalGoals($side1, $side2) * 100);
	}
	else
	{
		return 0;
	}
}

// takes the players array as input, and an empty array by reference
// fills the mostwinspids array with the pids of all players who have the max # of total wins
// and returns the number of players tied with this number
function getMostWinsPlayers( $players, &$pids )
{
	$max = 0;
	$numplayers = 0; // index for $maxwinpids
	
	foreach (array_keys($players) as $pid) 
	{
		$temp = $players[$pid]->getTotalWins();
		if (($temp > $max) && ($temp > 0)) // new max
		{
			$max = $temp;
			$numplayers = 0;
			$pids[$numplayers++] = $pid;
		}
		elseif (($temp == $max) && ($temp > 0)) // tied max
		{
			$pids[$numplayers++] = $pid;
		}
	}
			
	return $numplayers;
}

// takes the players array as input, and an empty array by reference
// fills the mostwinspids array with the pids of all players who have the max # of total goals
// and returns the number of players tied with this number
function getMostGoalsPlayers( $players, &$pids )
{
	$max = 0;
	$numplayers = 0; // index for $maxwinpids
	
	foreach (array_keys($players) as $pid) 
	{
		$temp = $players[$pid]->getTotalGoals();
		if (($temp > $max) && ($temp > 0)) // new max
		{
			$max = $temp;
			$numplayers = 0;
			$pids[$numplayers++] = $pid;
		}
		elseif (($temp == $max) && ($temp > 0)) // tied max
		{
			$pids[$numplayers++] = $pid;
		}
	}
			
	return $numplayers;
}

function getMostAvgGoalsPlayers( $players, &$pids )
{
	$max = 0;
	$numplayers = 0; // index for $maxwinpids
	
	foreach (array_keys($players) as $pid) 
	{
		$temp = $players[$pid]->getAvgGoals();
		if (($temp > $max) && ($temp > 0)) // new max
		{
			$max = $temp;
			$numplayers = 0;
			$pids[$numplayers++] = $pid;
		}
		elseif (($temp == $max) && ($temp > 0)) // tied max
		{
			$pids[$numplayers++] = $pid;
		}
	}
			
	return $numplayers;
}

function getMostGamesPlayers( $players, &$pids )
{
	$max = 0;
	$numplayers = 0; // index for $maxwinpids
	
	foreach (array_keys($players) as $pid) 
	{
		$temp = $players[$pid]->getTotalGames();
		if (($temp > $max) && ($temp > 0)) // new max
		{
			$max = $temp;
			$numplayers = 0;
			$pids[$numplayers++] = $pid;
		}
		elseif (($temp == $max) && ($temp > 0)) // tied max
		{
			$pids[$numplayers++] = $pid;
		}
	}
			
	return $numplayers;
}

function getMostShutoutsPlayers( $players, &$pids )
{
	$max = 0;
	$numplayers = 0; // index for $maxwinpids
	
	foreach (array_keys($players) as $pid) 
	{
		$temp = $players[$pid]->getShutouts();
		if (($temp > $max) && ($temp > 0)) // new max
		{
			$max = $temp;
			$numplayers = 0;
			$pids[$numplayers++] = $pid;
		}
		elseif (($temp == $max) && ($temp > 0)) // tied max
		{
			$pids[$numplayers++] = $pid;
		}
	}
			
	return $numplayers;
}

function getPercent( $nom, $denom )
{
	if ($denom == 0)
	{
		return 0;
	}
	else
	{
		return round($nom / $denom * 100);
	}
}

// individual player stats
function getPlayerData( $pid, &$player, &$leagues, &$partners )
{
	// get player's name
	$query = "SELECT firstName, lastName FROM foosball_player WHERE pid = $pid";
	$result = mysql_query($query)
		or die("Query failed:[" . mysql_errno() . "] " . mysql_error()) .
			__LINE__ . " in file " . __FILE__;
	
	if ($row = mysql_fetch_row( $result ))
	{
		$player->firstName = $row[0];
		$player->lastName = $row[1];
	}	
	mysql_free_result( $result );

	// get leagues player belongs to
	$query = "SELECT seasonId FROM foosball_leaguePlayer WHERE pid = $pid";
	$result = mysql_query($query)
		or die("Query failed:[" . mysql_errno() . "] " . mysql_error()) .
			__LINE__ . " in file " . __FILE__;
			
	$numleagues = mysql_num_rows($result); 
	
	// get league names
	while ($line = mysql_fetch_assoc( $result ))
	{
		$seasonId = $line['seasonId'];
		// get league name
		$query = "SELECT league FROM foosball_league WHERE seasonId = $seasonId";
		$league_result = mysql_query($query)
			or die("Query failed:[" . mysql_errno() . "] " . mysql_error()) .
				__LINE__ . " in file " . __FILE__;
		
		if ($row = mysql_fetch_row( $league_result ))
		{
			$leagues[$seasonId] = $row[0];
		}	
	} // while, get league names
	mysql_free_result( $result );
			
	// get all the game data
	$query = "SELECT * FROM foosball_game WHERE blueBackPlayer = $pid OR blueFrontPlayer = $pid OR whiteBackPlayer = $pid OR whiteFrontPlayer = $pid";
	$result = mysql_query($query)
		or die("Query failed:[" . mysql_errno() . "] " . mysql_error()) .
			__LINE__ . " in file " . __FILE__;	
			
	$numgames = mysql_num_rows($result);	
	
	while ($line = mysql_fetch_assoc( $result ))
	{
		if (($line['blueBackPlayer'] == $pid) && ($line['blueFrontPlayer'] == $pid)) // blue player, 1-on-1
		{
			$ppid = false; 
			$player->blueSingleGames++;
			$player->blueBackGoals += $line['blueBackScore'];
			$player->blueFrontGoals += $line['blueFrontScore'];
			
			if (($line['whiteFrontScore'] + $line['whiteBackScore']) <
				($line['blueFrontScore'] + $line['blueBackScore'])) // blue won
			{
				$player->blueSingleWins++;
				if (($line['whiteFrontScore'] + $line['whiteBackScore']) == 0) // white was shutout
				{
					$player->blueSingleShutouts++;
				}
			}
			else if (($line['blueFrontScore'] + $line['blueBackScore']) == 0)
			{
				$player->blueSingleShutoutLosses++;
			}
		}
		else if ($line['blueBackPlayer'] == $pid) // blue back player, with partner
		{
			$ppid = generateTeamKey($pid, $line['blueFrontPlayer']); 
			if (!array_key_exists($ppid, $partners))
			{
				$partners[$ppid] = new Team($pid, $line['blueFrontPlayer']);
			}
			$player->blueBackGames++;
			$player->blueBackGoals += $line['blueBackScore'];
			$partners[$ppid]->blueGames++;
			$partners[$ppid]->blueBackGoals += $line['blueBackScore'];
			
			if (($line['whiteFrontScore'] + $line['whiteBackScore']) <
				($line['blueFrontScore'] + $line['blueBackScore'])) // blue won
			{
				$player->blueBackWins++;
				$partners[$ppid]->blueWins++;
				if (($line['whiteFrontScore'] + $line['whiteBackScore']) == 0) // white was shutout
				{
					$player->blueBackShutouts++;
					$partners[$ppid]->blueShutouts++;
				}
			}
			else if (($line['blueFrontScore'] + $line['blueBackScore']) == 0)
			{
				$player->blueBackShutoutLosses++;
				$partners[$ppid]->blueShutoutLosses++;
			}
		}
		else if ($line['blueFrontPlayer'] == $pid) // blue front player, with partner
		{
			$ppid = generateTeamKey($line['blueBackPlayer'], $pid); 
			if (!array_key_exists($ppid, $partners))
			{
				$partners[$ppid] = new Team($line['blueBackPlayer'], $pid);
			}
			$player->blueFrontGames++;
			$player->blueFrontGoals += $line['blueFrontScore'];
			$partners[$ppid]->blueGames++;
			$partners[$ppid]->blueFrontGoals += $line['blueFrontScore'];
			
			if (($line['whiteFrontScore'] + $line['whiteBackScore']) <
				($line['blueFrontScore'] + $line['blueBackScore'])) // blue won
			{
				$player->blueFrontWins++;
				$partners[$ppid]->blueWins++;
				if (($line['whiteFrontScore'] + $line['whiteBackScore']) == 0) // white was shutout
				{
					$player->blueFrontShutouts++;
					$partners[$ppid]->blueShutouts++;
				}
			}
			else if (($line['blueFrontScore'] + $line['blueBackScore']) == 0)
			{
				$player->blueFrontShutoutLosses++;
				$partners[$ppid]->blueShutoutLosses++;
			}
		}
		else if (($line['whiteBackPlayer'] == $pid) && ($line['whiteFrontPlayer'] == $pid)) // white player, 1-on-1
		{
			$ppid = false; 
			$player->whiteSingleGames++;
			$player->whiteBackGoals += $line['whiteBackScore'];
			$player->whiteFrontGoals += $line['whiteFrontScore'];
			
			if (($line['blueFrontScore'] + $line['blueBackScore']) <
				($line['whiteFrontScore'] + $line['whiteBackScore'])) // white won
			{
				$player->whiteSingleWins++;
				if (($line['blueFrontScore'] + $line['blueBackScore']) == 0) // blue was shutout
				{
					$player->whiteSingleShutouts++;
				}
			}
			else if (($line['whiteFrontScore'] + $line['whiteBackScore']) == 0)
			{
				$player->whiteSingleShutoutLosses++;
			}
		}
		else if ($line['whiteBackPlayer'] == $pid) // white back player, with partner
		{
			$ppid = generateTeamKey($pid, $line['whiteFrontPlayer']); 
			if (!array_key_exists($ppid, $partners))
			{
				$partners[$ppid] = new Team($pid, $line['whiteFrontPlayer']);
			}
			$player->whiteBackGames++;
			$player->whiteBackGoals += $line['whiteBackScore'];
			$partners[$ppid]->whiteGames++;
			$partners[$ppid]->whiteBackGoals += $line['whiteBackScore'];
			
			if (($line['blueFrontScore'] + $line['blueBackScore']) <
				($line['whiteFrontScore'] + $line['whiteBackScore'])) // white won
			{
				$player->whiteBackWins++;
				$partners[$ppid]->whiteWins++;
				if (($line['blueFrontScore'] + $line['blueBackScore']) == 0) // blue was shutout
				{
					$player->whiteBackShutouts++;
					$partners[$ppid]->whiteShutouts++;
				}
			}
			else if (($line['whiteFrontScore'] + $line['whiteBackScore']) == 0)
			{
				$player->whiteBackShutoutLosses++;
				$partners[$ppid]->whiteShutoutLosses++;
			}
		}
		else if ($line['whiteFrontPlayer'] == $pid) // white front player, with partner
		{
			$ppid = generateTeamKey($line['whiteBackPlayer'], $pid); 
			if (!array_key_exists($ppid, $partners))
			{
				$partners[$ppid] = new Team($line['whiteBackPlayer'], $pid);
			}
			$player->whiteFrontGames++;
			$player->whiteFrontGoals += $line['whiteFrontScore'];
			$partners[$ppid]->whiteGames++;
			$partners[$ppid]->whiteFrontGoals += $line['whiteFrontScore'];
			
			if (($line['blueFrontScore'] + $line['blueBackScore']) <
				($line['whiteFrontScore'] + $line['whiteBackScore'])) // white won
			{
				$player->whiteFrontWins++;
				$partners[$ppid]->whiteWins++;
				if (($line['blueFrontScore'] + $line['blueBackScore']) == 0) // blue was shutout
				{
					$player->whiteFrontShutouts++;
					$partners[$ppid]->whiteShutouts++;
				}
			}
			else if (($line['whiteFrontScore'] + $line['whiteBackScore']) == 0)
			{
				$player->whiteFrontShutoutLosses++;
				$partners[$ppid]->whiteShutoutLosses++;
			}
		}		
	} // while, get game data
	mysql_free_result( $result );
	
	// get all partner names
	foreach (array_keys($partners) as $ppid)
	{
		$frontPlayer = $partners[$ppid]->frontPlayer;
		$backPlayer = $partners[$ppid]->backPlayer;
		
		if ($frontPlayer == $pid)
		{
			$query = "SELECT firstName, lastName FROM foosball_player WHERE pid = $backPlayer";
		}
		else
		{
			$query = "SELECT firstName, lastName FROM foosball_player WHERE pid = $frontPlayer";
		}
				
		$result = mysql_query($query)
			or die("Query failed:[" . mysql_errno() . "] " . mysql_error()) .
				__LINE__ . " in file " . __FILE__;
		
		if ($row = mysql_fetch_row( $result ))
		{
			$firstName = $row[0];
			$lastName = $row[1];
		}
		
		if ($frontPlayer == $pid)
		{
			$partners[$ppid]->backPlayer = $firstName." ".$lastName;
		}
		else
		{
			$partners[$ppid]->frontPlayer = $firstName." ".$lastName;
		}
	} // foreach
} // getPlayerData()

function getFavouritePosition($player)
{
	if ($player->getTotalGames() == 0)
	{
		return "<em>N/A</em>";
	}
	
	$frontPercent = $player->getFrontGames() / $player->getTotalGames();
	$backPercent = $player->getBackGames() / $player->getTotalGames();
	$singlePercent = $player->getSingleGames() / $player->getTotalGames();
	$max = max($frontPercent, $backPercent, $singlePercent);
	$bdiff = abs($max - $backPercent);
	$fdiff = abs($max - $frontPercent);
	$sdiff = abs($max - $singlePercent);
	
	if ($bdiff < THRESHOLD)
	{
		if ($fdiff < THRESHOLD)
		{
			if ($sdiff < THRESHOLD)
			{
				return "Front/Back/Single";
			}
			else
			{
				return "Front/Back";
			}
		}
		else if ($sdiff < THRESHOLD)
		{
			return "Back/Single";
		}
		else
		{
			return "Back";
		}
	}
	else if ($fdiff < THRESHOLD)
	{
		if ($sdiff < THRESHOLD)
		{
			return "Front/Single";
		}
		else
		{
			return "Front";
		}
	}
	else 
	{
		return "Single";
	}
}

function getStrongestPosition($player)
{
	if ($player->getTotalGames() == 0)
	{
		return "<em>N/A</em>";
	}
	else if ($player->getFrontGames() == 0)
	{
		return "Back (never played front)";
	}
	else if ($player->getBackGames() == 0)
	{
		return "Front (never played back)";
	}
	
	$frontPercent = $player->getFrontGoals() / $player->getFrontGames();
	$backPercent = $player->getBackGoals() / $player->getBackGames();
	$diff = abs($frontPercent - $backPercent);
	
	if ($diff < THRESHOLD)
	{
		return "Front/Back";
	}
	else if ($frontPercent > $backPercent)
	{
		return "Front";
	}
	else 
	{
		return "Back";
	}
}

function getFavouritePartners( $player, $partners, &$ppids )
{
	$max = 0;
	$numplayers = 0; // index for $maxwinpids
	
	foreach (array_keys($partners) as $ppid) 
	{
		$max = max(($partners[$ppid]->getTotalGames() / $player->getTotalGames()), $max);
	}
	
	foreach (array_keys($partners) as $ppid) 
	{
		$temp = $partners[$ppid]->getTotalGames() / $player->getTotalGames();
		$diff = $max - $temp;
		if ($diff < THRESHOLD) // new max
		{
			$ppids[$numplayers++] = $ppid;
		}
	}
			
	return $numplayers;
}

function getStrongestPartners( $player, $partners, &$ppids )
{
	$max = 0;
	$numplayers = 0; // index for $maxwinpids
	
	foreach (array_keys($partners) as $ppid) 
	{
		$max = max(($partners[$ppid]->getTotalWins() / $partners[$ppid]->getTotalGames()), $max);
	}
	
	foreach (array_keys($partners) as $ppid) 
	{
		$temp = $partners[$ppid]->getTotalWins() / $partners[$ppid]->getTotalGames();
		$diff = $max - $temp;
		if ($diff < THRESHOLD) 
		{
			$ppids[$numplayers++] = $ppid;
		}
	}
			
	return $numplayers;
}
		
?>